CREATE SCHEMA Bauliche_Strasseneigenschaften

-- Historie:
--
-- 29.06.2004 - 1.004 (1.009)
-- Anpassung an ASB-Netzdaten, Stand September 2002
-- Verlegung der Kreuzungen in eigenes Schema
--
-- 03.09.2003 - 1.003 (1.008)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
-- Korrektur der historischen Gltigkeitsdaten (SQL)
--
-- 31.05.2002 - 1.002 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 11.12.2000 - 1.001 (1.002)
-- Symbolische Verweise integriert fr Teilbauwerk
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Schicht (
   Schicht_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Schicht_ID) REFERENCES Strassennetz.Streckenobjekt_hist,
   FOREIGN KEY (Schicht_ID) REFERENCES Geometrieschema.Volumenobjekt_Modell,
   maximale_Korngroesse
      REAL, -- Millimeter
   CHECK ( maximale_Korngroesse >= 0 ),
   Einbaudatum
      CHAR(10), -- Datum
   CHECK ( Einbaudatum LIKE '__.__.____' )
)

CREATE TABLE Schicht__beg_bei_Schichtbegr (
   Schicht
      INTEGER NOT NULL REFERENCES Schicht,
   Schichtbegrenzung
      INTEGER NOT NULL REFERENCES Schichtbegrenzung
)

CREATE TABLE Schicht__endet_bei_Schichtbegr (
   Schicht
      INTEGER NOT NULL REFERENCES Schicht,
   Schichtbegrenzung
      INTEGER NOT NULL REFERENCES Schichtbegrenzung
)

CREATE TABLE Schicht__hat_Schichtart (
   Schicht
      INTEGER NOT NULL REFERENCES Schicht,
   Schichtart
      INTEGER NOT NULL REFERENCES Schichtart
)

CREATE TABLE Schicht__hat_Schichtmaterial (
   Schicht
      INTEGER NOT NULL REFERENCES Schicht,
   Schichtmaterial
      INTEGER NOT NULL REFERENCES Schichtmaterial
)

CREATE TABLE Schicht__unter_Schicht (
   Schicht
      INTEGER NOT NULL REFERENCES Schicht,
   Schicht_2
      INTEGER NOT NULL REFERENCES Schicht
)

CREATE TABLE Schichtbegrenzung (
   Schichtbegrenzung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Schichtbegrenzung_ID) REFERENCES Strassennetz.Punktobjekt_hist,
   Breite
      REAL, -- Meter
   Achsabstand_Anfang
      REAL, -- Meter
   Dicke
      REAL, -- Zentimeter
   CHECK ( Dicke >= 0 ),
   Abstand_Planum
      REAL, -- Millimeter
   CHECK ( Abstand_Planum >= 0 )
)

CREATE TABLE Schichtart (
   Schichtart_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Schichtart_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Kennung_Schichtart
      INTEGER,
   Kurztext
      VARCHAR(18),
   Schichtbeschreibung
      VARCHAR(29)
)

CREATE TABLE Schichtmaterial (
   Schichtmaterial_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Schichtmaterial_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Schichtmaterial_Kennung
      INTEGER,
   Schichtmaterial_Kurzbezeichng
      VARCHAR(18),
   Schichtmaterial_Beschreibung
      VARCHAR(29)
)

CREATE TABLE Querschnittstreifen (
   Querschnittstreifen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Querschnittstreifen_ID) REFERENCES Strassennetz.Streckenobjekt_hist,
   FOREIGN KEY (Querschnittstreifen_ID) REFERENCES Geometrieschema.Flaechenobjekt_Modell
)

CREATE TABLE Querschnstr__beg_bei_Streifbeg (
   Querschnittstreifen
      INTEGER NOT NULL REFERENCES Querschnittstreifen,
   Streifenbegrenzung
      INTEGER NOT NULL REFERENCES Streifenbegrenzung
)

CREATE TABLE Querschnstr__end_bei_Streifbeg (
   Querschnittstreifen
      INTEGER NOT NULL REFERENCES Querschnittstreifen,
   Streifenbegrenzung
      INTEGER NOT NULL REFERENCES Streifenbegrenzung
)

CREATE TABLE Querschnstr__hat_Streifenart (
   Querschnittstreifen
      INTEGER NOT NULL REFERENCES Querschnittstreifen,
   Streifenart
      INTEGER NOT NULL REFERENCES Streifenart
)

CREATE TABLE Streifenart (
   Streifenart_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Streifenart_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Kennung
      INTEGER,
   Streifenart
      VARCHAR(250)
)

CREATE TABLE Streifenbegrenzung (
   Streifenbegrenzung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Streifenbegrenzung_ID) REFERENCES Strassennetz.Punktobjekt_hist,
   FOREIGN KEY (Streifenbegrenzung_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   Streifenbreite
      REAL -- Meter
)

CREATE TABLE Bauklasse_Oberbau (
   Bauklasse_Oberbau_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bauklasse_Oberbau_ID) REFERENCES Strassennetz.Streckenobjekt_hist,
   Strassenoberbau
      VARCHAR(29)
)

CREATE TABLE Bauweise_Oberbau (
   Bauweise_Oberbau_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bauweise_Oberbau_ID) REFERENCES Strassennetz.Streckenobjekt_hist,
   Oberbauweise
      VARCHAR(29)
)

CREATE TABLE Regelquerschnitt (
   Regelquerschnitt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Regelquerschnitt_ID) REFERENCES Strassennetz.Streckenobjekt_hist,
   Kennzeichen_Regelquerschnitt
      VARCHAR(10)
)

CREATE TABLE Bahnigkeit (
   Bahnigkeit_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bahnigkeit_ID) REFERENCES Strassennetz.Streckenobjekt_hist,
   Kennzeichen_Bahnigkeit
      INTEGER REFERENCES Kennzeichen_Bahnigkeit
)

CREATE TABLE Kennzeichen_Bahnigkeit (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Kennzeichen_Bahnigkeit VALUES (1,'einbahnig, Strae mit/ohne Gegenverkehr')
INSERT INTO Kennzeichen_Bahnigkeit VALUES (2,'zweibahnig, Strae mit baulich getrennten Richtungsfahrbahnen')

CREATE TABLE Fahrbahnlaengsneigung (
   Fahrbahnlaengsneigung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Fahrbahnlaengsneigung_ID) REFERENCES Strassennetz.Streckenobjekt_hist,
   FOREIGN KEY (Fahrbahnlaengsneigung_ID) REFERENCES Geometrieschema.Flaechenobjekt_Modell,
   Steigung_Gefaelle
      REAL -- Prozent
)

CREATE TABLE Fahrbahnquerneigung (
   Fahrbahnquerneigung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Fahrbahnquerneigung_ID) REFERENCES Strassennetz.Streckenobjekt_hist,
   FOREIGN KEY (Fahrbahnquerneigung_ID) REFERENCES Geometrieschema.Flaechenobjekt_Modell,
   Querneigung
      REAL -- Prozent
)

CREATE TABLE Fahrbahntrennung (
   Fahrbahntrennung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Fahrbahntrennung_ID) REFERENCES Strassennetz.Streckenobjekt_stat,
   Art_der_Trennung
      CHAR(1)
)

CREATE TABLE Trassenbreite (
   Trassenbreite_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Trassenbreite_ID) REFERENCES Strassennetz.Streckenobjekt_stat,
   Trassenbreite
      REAL -- Meter
)

CREATE TABLE Fahrbahnbreite (
   Fahrbahnbreite_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Fahrbahnbreite_ID) REFERENCES Strassennetz.Streckenobjekt_stat,
   Fahrbahnbreite
      REAL -- Meter
)

CREATE TABLE Fussweg (
   Fussweg_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Fussweg_ID) REFERENCES Strassennetz.Streckenobjekt_stat
)

CREATE TABLE Radweg (
   Radweg_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Radweg_ID) REFERENCES Strassennetz.Streckenobjekt_stat
)

CREATE TABLE Schutzzone (
   Schutzzone_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Schutzzone_ID) REFERENCES Strassennetz.Bereichsobjekt_hist,
   Kennung_Schutzzone
      CHAR(1),
   Text_Schutzzone
      VARCHAR(29)
)

CREATE TABLE Hindernis (
   Hindernis_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Hindernis_ID) REFERENCES Strassennetz.Streckenobjekt_hist,
   passierbare_Hoehe
      REAL, -- Millimeter
   CHECK ( passierbare_Hoehe >= 0 ),
   passierbare_Breite
      REAL, -- Millimeter
   CHECK ( passierbare_Breite >= 0 ),
   Belastungsgrenzwert_Hindernis
      REAL, -- Tonnen
   CHECK ( Belastungsgrenzwert_Hindernis >= 0 ),
   Laenge_des_Hindernisses
      REAL, -- Meter
   Hindernisart
      INTEGER REFERENCES Hindernis_Art
)

CREATE TABLE Hindernis__ist_Bauwerk (
   Hindernis
      INTEGER NOT NULL REFERENCES Hindernis,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Bauwerke.Teilbauwerk_abstrakt
)

CREATE TABLE Hindernis_Art (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Hindernis_Art VALUES (1,'Tunnel')
INSERT INTO Hindernis_Art VALUES (2,'Brcken oder hnliche Konstruktionen (z.B. Stadttor)')
INSERT INTO Hindernis_Art VALUES (3,'grere Konstruktionen neben der Fahrbahn (z.B. Huser) sowie Masten und Mastenreihen')
INSERT INTO Hindernis_Art VALUES (4,'Fels, Steilbschung')
INSERT INTO Hindernis_Art VALUES (5,'Mauern, Zune, Gelnder')
INSERT INTO Hindernis_Art VALUES (6,'Bume, Alleen')
INSERT INTO Hindernis_Art VALUES (7,'(kreuzende) berspannungen (bei Elektrizittsleitungen Achtung Lebensgefahr! Nicht messen!)')
INSERT INTO Hindernis_Art VALUES (8,'Rckbau wegen Geschwindigkeitsreduzierung')
INSERT INTO Hindernis_Art VALUES (9,'sonstige Hindernisse (z.B. Verkehrszeichen auf 2 Pfosten, Hydranten, Laderampen)')

CREATE TABLE Durchlass (
   Durchlass_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Durchlass_ID) REFERENCES Strassennetz.Punktobjekt_hist,
   Ueberdeckung
      REAL, -- Meter
   Durchlasslaenge
      REAL, -- Meter
   Durchlassart
      VARCHAR(30)
)

CREATE TABLE Durchlass__hat_Baustoff (
   Durchlass
      INTEGER NOT NULL REFERENCES Durchlass,
   Baustoff
      INTEGER NOT NULL REFERENCES Baustoff
)

CREATE TABLE Durchlass__hat_Profil (
   Durchlass
      INTEGER NOT NULL REFERENCES Durchlass,
   Profil
      INTEGER NOT NULL REFERENCES Profil
)

CREATE TABLE Durchlass__hat_Leitung (
   Durchlass
      INTEGER NOT NULL REFERENCES Durchlass,
   Leitung
      INTEGER NOT NULL REFERENCES Strassenausstattungen.Leitung
)

CREATE TABLE Baustoff (
   Baustoff_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Baustoff_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Material
      VARCHAR(30)
)

CREATE TABLE Profil (
   Profil_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Profil_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Profilform
      INTEGER REFERENCES Profilform,
   Profilhoehe
      REAL, -- Zentimeter
   CHECK ( Profilhoehe >= 0 ),
   Profilbreite
      REAL, -- Zentimeter
   CHECK ( Profilbreite >= 0 )
)

CREATE TABLE Profilform (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Profilform VALUES (1,'Kreisprofil')
INSERT INTO Profilform VALUES (2,'Eiprofil')
INSERT INTO Profilform VALUES (3,'Kastenprofil')
INSERT INTO Profilform VALUES (4,'Maulprofil')
INSERT INTO Profilform VALUES (5,'Haubenprofil')

