CREATE SCHEMA Strassenausstattungen

-- Historie:
--
-- 29.06.2004 - 1.004 (1.009)
-- Dokument in Schema Allgemeine Objekte verlegt
--
-- 03.09.2003 - 1.003 (1.008)
-- Korrektur der historischen Gltigkeitsdaten (SQL)
--
-- 31.05.2002 - 1.002 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 07.03.2001 - 1.001 (1.003)
-- Korrektur der FOREIGN KEY Referenz fr Leitung
-- von Strassenausstattung auf Ausstattung_und_Anlagen (SQL)
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Ausstattung_und_Anlagen (
   Ausstattung_und_Anlagen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Ausstattung_und_Anlagen_ID) REFERENCES Strassennetz.Streckenobjekt_hist,
   Art_Ausstattung_und_Anlagen
      INTEGER NOT NULL REFERENCES Art_Ausstattung_und_Anlagen,
   Kennzeichen
      CHAR(1),
   Beschreibungstext
      VARCHAR(30),
   Ort_am_Fahrstreifen
      CHAR(1) REFERENCES Tab_Markierung, -- Markierung
   Lage_zum_Fahrstreifen
      CHAR(1), -- Schutzplanke
   Plankenart
      VARCHAR(30) -- Schutzplanke
)

CREATE TABLE Art_Ausstattung_und_Anlagen (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(20) NOT NULL
)

INSERT INTO Art_Ausstattung_und_Anlagen VALUES ( 5003, 'Nebenanlage' )
INSERT INTO Art_Ausstattung_und_Anlagen VALUES ( 5005, 'Rastanlage_nicht_bew' )
INSERT INTO Art_Ausstattung_und_Anlagen VALUES ( 5006, 'Rastanlage_bew' )
INSERT INTO Art_Ausstattung_und_Anlagen VALUES ( 5007, 'Nebenbetrieb' )
INSERT INTO Art_Ausstattung_und_Anlagen VALUES ( 5008, 'Leitung' )
INSERT INTO Art_Ausstattung_und_Anlagen VALUES ( 5012, 'Markierung' )
INSERT INTO Art_Ausstattung_und_Anlagen VALUES ( 5014, 'Schutzplanke' )

CREATE TABLE Leitung (
   Leitung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Leitung_ID) REFERENCES Ausstattung_und_Anlagen
)

CREATE TABLE Leitung__hat_Leitungsverlauf (
   Leitung
      INTEGER NOT NULL REFERENCES Leitung,
   Leitungsverlauf
      INTEGER NOT NULL REFERENCES Leitungsverlauf
)

CREATE TABLE Leitung__hat_Profil (
   Leitung
      INTEGER NOT NULL REFERENCES Leitung,
   Profil
      INTEGER NOT NULL REFERENCES Bauliche_Strasseneigenschaften.Profil
)

CREATE TABLE Leitung__hat_Leitungstraeger (
   Leitung
      INTEGER NOT NULL REFERENCES Leitung,
   Leitungstraeger
      INTEGER NOT NULL REFERENCES Leitungstraeger
)

CREATE TABLE Leitung__hat_Leitungsart (
   Leitung
      INTEGER NOT NULL REFERENCES Leitung,
   Leitungsart
      INTEGER NOT NULL REFERENCES Leitungsart
)

CREATE TABLE Leitung__hat_Baustoff (
   Leitung
      INTEGER NOT NULL REFERENCES Leitung,
   Baustoff
      INTEGER NOT NULL REFERENCES Bauliche_Strasseneigenschaften.Baustoff
)

CREATE TABLE Leitung__hat_Dokument (
   Leitung
      INTEGER NOT NULL REFERENCES Leitung,
   Dokument_abstrakt
      INTEGER NOT NULL REFERENCES Allgemeine_Objekte.Dokument_abstrakt
)

CREATE TABLE Leitungsverlauf (
   Leitungsverlauf_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Leitungsverlauf_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Leitungslage
      REAL -- Meter
)

CREATE TABLE Leitungstraeger (
   Leitungstraeger_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Leitungstraeger_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Leitungstraeger_Kurzform
      CHAR(1),
   Leitungstraeger_Langform
      VARCHAR(29)
)

CREATE TABLE Leitungsart (
   Leitungsart_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Leitungsart_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Kennung_Leitungsart
      CHAR(1),
   Leitungsart_Langtext
      VARCHAR(29)
)

CREATE TABLE Tab_Markierung (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Tab_Markierung VALUES ('R','rechts')
INSERT INTO Tab_Markierung VALUES ('L','links')
INSERT INTO Tab_Markierung VALUES ('B','beidseitig')

CREATE TABLE Strassenentwaesserung (
   Strassenentwaesserung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Strassenentwaesserung_ID) REFERENCES Strassennetz.Streckenobjekt_stat
)

CREATE TABLE Strassenentw__hat_entw_Fahrbfl (
   Strassenentwaesserung
      INTEGER NOT NULL REFERENCES Strassenentwaesserung,
   entwaesserte_Fahrbahnflaeche
      INTEGER NOT NULL REFERENCES entwaesserte_Fahrbahnflaeche
)

CREATE TABLE Strassenentw__hat_Lage_Entw (
   Strassenentwaesserung
      INTEGER NOT NULL REFERENCES Strassenentwaesserung,
   Lage_Entwaesserung
      INTEGER NOT NULL REFERENCES Lage_Entwaesserung
)

CREATE TABLE Strassenentw__hat_Art_d_Entw (
   Strassenentwaesserung
      INTEGER NOT NULL REFERENCES Strassenentwaesserung,
   Art_der_Entwaesserung
      INTEGER NOT NULL REFERENCES Art_der_Entwaesserung
)

CREATE TABLE Strassenentw__hat_Dokument (
   Strassenentwaesserung
      INTEGER NOT NULL REFERENCES Strassenentwaesserung,
   Dokument_abstrakt
      INTEGER NOT NULL REFERENCES Allgemeine_Objekte.Dokument_abstrakt
)

CREATE TABLE entwaesserte_Fahrbahnflaeche (
   entwaess_Fahrbahnflaeche_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (entwaess_Fahrbahnflaeche_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   entwaesserter_Fahrbahnteil
      CHAR(1),
   Flaeche
      REAL, -- Quadratmeter
   CHECK ( Flaeche >= 0 )
)

CREATE TABLE Lage_Entwaesserung (
   Lage_Entwaesserung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Lage_Entwaesserung_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Lage
      CHAR(1) REFERENCES Lage,
   Einleitung
      CHAR(1) REFERENCES Einleitung
)

CREATE TABLE Lage (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Lage VALUES ('R','rechts der Strae')
INSERT INTO Lage VALUES ('L','links der Strae')
INSERT INTO Lage VALUES ('F','auf der Fahrbahn')

CREATE TABLE Einleitung (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Einleitung VALUES ('P','punktfrmige Einleitung')
INSERT INTO Einleitung VALUES ('S','Streckeneinleitung')

CREATE TABLE Art_der_Entwaesserung (
   Art_der_Entwaesserung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Art_der_Entwaesserung_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Transporteinrichtung
      VARCHAR(40),
   Behandlung
      VARCHAR(40),
   Ableitung
      VARCHAR(40)
)

CREATE TABLE Art_der_Entwaess__hat_Leitung (
   Art_der_Entwaesserung
      INTEGER NOT NULL REFERENCES Art_der_Entwaesserung,
   Leitung
      INTEGER NOT NULL REFERENCES Leitung
)

