CREATE SCHEMA Strassenzustandsdaten

-- Historie:
--
-- 03.09.2003 - 1.003 (1.008)
-- Relationsrichtungen getauscht gem A0025
-- Werte fr Art_ZEB_Parameter und Art_ZEB_Methode ergnzt
--
-- 31.05.2002 - 1.002 (1.007)
-- Krzung berlanger SQL-Bezeichner
--
-- 29.11.2001 - 1.001 (1.006)
-- berarbeitung der Zustandsdaten
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE ZEB_Objekt (
   ZEB_Objekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (ZEB_Objekt_ID) REFERENCES Strassennetz.Streckenobjekt_stat,
   ZEB_Objekt
      VARCHAR(30),
   Objektnummer
      INTEGER,
   hat_Verkehrsrichtung
      CHAR(1) NOT NULL REFERENCES Verkehr.Verkehrsrichtung
)

CREATE TABLE ZEB_Objekt__gilt_f_Querschnstr (
   ZEB_Objekt
      INTEGER NOT NULL REFERENCES ZEB_Objekt,
   Querschnittstreifen
      INTEGER NOT NULL REFERENCES Bauliche_Strasseneigenschaften.Querschnittstreifen
)

CREATE TABLE ZEB_Objekt__gilt_f_Fahrstreif (
   ZEB_Objekt
      INTEGER NOT NULL REFERENCES ZEB_Objekt,
   Fahrstreifen_Nummer
      INTEGER NOT NULL REFERENCES Verkehr.Fahrstreifen_Nummer
)

CREATE TABLE ZEB_Objekt__von_ZEB_Projekt (
   ZEB_Objekt
      INTEGER NOT NULL REFERENCES ZEB_Objekt,
   ZEB_Projekt
      INTEGER NOT NULL REFERENCES ZEB_Projekt
)

CREATE TABLE ZEB_Objekt__hat_Art_d_ZEB_Obj (
   ZEB_Objekt
      INTEGER NOT NULL REFERENCES ZEB_Objekt,
   Art_des_ZEB_Objektes
      INTEGER NOT NULL REFERENCES Art_des_ZEB_Objektes
)

CREATE TABLE ZEB_Projekt (
   ZEB_Projekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Kurzbezeichnung_ZEB_Kamp
      VARCHAR(8),
   ZEB_Projekt
      VARCHAR(20),
   Hauptmessverfahren
      VARCHAR(20),
   Zweck
      VARCHAR(100),
   Umfang
      VARCHAR(200),
   hat_ZEB_Parameterliste
      INTEGER NOT NULL REFERENCES ZEB_Parameterliste
)

CREATE TABLE ZEB_Projekt__hat_Zeitraum (
   ZEB_Projekt
      INTEGER NOT NULL REFERENCES ZEB_Projekt,
   Zeitraum
      INTEGER NOT NULL REFERENCES Allgemeine_Objekte.Zeitraum
)

CREATE TABLE ZEB_Projekt__hat_ZEB_Ereignis (
   ZEB_Projekt
      INTEGER NOT NULL REFERENCES ZEB_Projekt,
   ZEB_Ereignis
      INTEGER NOT NULL REFERENCES ZEB_Ereignis
)

CREATE TABLE ZEB_Projekt__hat_ZEB_Subjekt (
   ZEB_Projekt
      INTEGER NOT NULL REFERENCES ZEB_Projekt,
   ZEB_Subjekt
      INTEGER NOT NULL REFERENCES ZEB_Subjekt
)

CREATE TABLE ZEB_Parameterwert (
   ZEB_Parameterwert_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_ZEB_Parameterwert
      INTEGER NOT NULL REFERENCES Art_ZEB_Parameterwert,
   Wert
      VARCHAR(255),
   von_ZEB_Objekt
      INTEGER NOT NULL REFERENCES ZEB_Objekt,
   von_ZEB_Parameter
      INTEGER NOT NULL REFERENCES ZEB_Parameter,
   von_ZEB_Ereignis
      INTEGER NOT NULL REFERENCES ZEB_Ereignis
)

CREATE TABLE Art_ZEB_Parameterwert (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(26) NOT NULL
)

INSERT INTO Art_ZEB_Parameterwert VALUES ( 6005, 'Wert_einer_Zustandsgroesse' )
INSERT INTO Art_ZEB_Parameterwert VALUES ( 6006, 'Wert_eines_Zustandswertes' )
INSERT INTO Art_ZEB_Parameterwert VALUES ( 6007, 'Wert_eines_Teilwertes' )
INSERT INTO Art_ZEB_Parameterwert VALUES ( 6008, 'Wert_eines_Gesamtwertes' )
INSERT INTO Art_ZEB_Parameterwert VALUES ( 6009, 'Wert_eines_Rohdatums' )

CREATE TABLE Art_des_ZEB_Objektes (
   Art_des_ZEB_Objektes_ID
      INTEGER NOT NULL PRIMARY KEY,
   Kurzbezeichnung_Objektart
      VARCHAR(8),
   ZEB_Objektart
      VARCHAR(30)
)

CREATE TABLE ZEB_Parameter (
   ZEB_Parameter_ID
      INTEGER NOT NULL PRIMARY KEY,
   Kurzbezeichnung_Paramgroesse
      VARCHAR(8),
   Parametergroesse
      VARCHAR(30),
   Parameternummer
      INTEGER,
   Einheit
      VARCHAR(8),
   Art_ZEB_Parameter
      INTEGER NOT NULL REFERENCES Art_ZEB_Parameter,
   Art_ZEB_Methode
      INTEGER NOT NULL REFERENCES Art_ZEB_Methode,
   hat_ZEB_Dokument
      INTEGER NOT NULL REFERENCES ZEB_Dokument
)

CREATE TABLE ZEB_Dokument (
   ZEB_Dokument_ID
      INTEGER NOT NULL PRIMARY KEY,
   Kurzbezeichnung_ZEB_Dokument
      VARCHAR(8),
   ZEB_Dokument
      VARCHAR(20),
   Datum_der_Erstellung
      CHAR(10), -- Datum
   CHECK ( Datum_der_Erstellung LIKE '__.__.____' ),
   Ersteller
      VARCHAR(30),
   Art_des_Dokumentes
      VARCHAR(20)
)

CREATE TABLE ZEB_Ereignis (
   ZEB_Ereignis_ID
      INTEGER NOT NULL PRIMARY KEY,
   Kurzbezeichnung_ZEB_Ereignis
      VARCHAR(8),
   ZEB_Ereignis
      VARCHAR(20),
   hat_ZEB_Dokument
      INTEGER REFERENCES ZEB_Dokument
)

CREATE TABLE ZEB_Ereignis__hat_Zeitraum (
   ZEB_Ereignis
      INTEGER NOT NULL REFERENCES ZEB_Ereignis,
   Zeitraum
      INTEGER NOT NULL REFERENCES Allgemeine_Objekte.Zeitraum
)

CREATE TABLE ZEB_Ereignis__hat_ZEB_Subjekt (
   ZEB_Ereignis
      INTEGER NOT NULL REFERENCES ZEB_Ereignis,
   ZEB_Subjekt
      INTEGER NOT NULL REFERENCES ZEB_Subjekt
)

CREATE TABLE ZEB_Subjekt (
   ZEB_Subjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_ZEB_Subjekt
      INTEGER NOT NULL REFERENCES Art_ZEB_Subjekt,
   Kurzbezeichnung_Subjekt
      VARCHAR(8),
   Subjekt
      VARCHAR(20),
   Adresse_Subjekt
      VARCHAR(100)
)

CREATE TABLE Art_ZEB_Subjekt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(15) NOT NULL
)

INSERT INTO Art_ZEB_Subjekt VALUES ( 6013, 'ZEB_Erfasser' )
INSERT INTO Art_ZEB_Subjekt VALUES ( 6014, 'ZEB_Bewerter' )
INSERT INTO Art_ZEB_Subjekt VALUES ( 6015, 'ZEB_Veranlasser' )

CREATE TABLE ZEB_Parameterliste (
   ZEB_Parameterliste_ID
      INTEGER NOT NULL PRIMARY KEY,
   Kurzbezeichnung_ZEB_Paramliste
      VARCHAR(8),
   Bezeichnung_ZEB_Parameterliste
      VARCHAR(20)
)

CREATE TABLE ZEB_Paramliste__hat_ZEB_Param (
   ZEB_Parameterliste
      INTEGER NOT NULL REFERENCES ZEB_Parameterliste,
   ZEB_Parameter
      INTEGER NOT NULL REFERENCES ZEB_Parameter
)

CREATE TABLE Art_ZEB_Parameter (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(20) NOT NULL
)

INSERT INTO Art_ZEB_Parameter VALUES (1,'Zustandsgroesse')
INSERT INTO Art_ZEB_Parameter VALUES (2,'Zustandswert')
INSERT INTO Art_ZEB_Parameter VALUES (3,'Teilwert')
INSERT INTO Art_ZEB_Parameter VALUES (4,'Gesamtwert')
INSERT INTO Art_ZEB_Parameter VALUES (5,'Rohdatum')

CREATE TABLE Art_ZEB_Methode (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(40) NOT NULL
)

INSERT INTO Art_ZEB_Methode VALUES (1,'Zustandsmessverfahren')
INSERT INTO Art_ZEB_Methode VALUES (2,'ZEB_visuell_sensit_Wahrnehmung')
INSERT INTO Art_ZEB_Methode VALUES (3,'Aggregationsmethode')
INSERT INTO Art_ZEB_Methode VALUES (4,'Normierungsmethode')
INSERT INTO Art_ZEB_Methode VALUES (5,'Kombinationsmethode')
INSERT INTO Art_ZEB_Methode VALUES (6,'Klassifizierungsmethode')

