CREATE SCHEMA automat_Dauerzaehlstelle

-- Historie:
--
-- 29.06.2004 - 1.005 (1.009)
-- Krzung von Bezeichnern, vernderte Schlssel (SQL)
--
-- 03.09.2003 - 1.004 (1.008)
-- berarbeitung gem N0049
--
-- 31.05.2002 - 1.003 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 12.09.2001 - 1.002 (1.004)
-- formale Versionierung durch Versionierung Verkehrsstaerke:
-- Bezug zum Unfall hergestellt nach berarbeitung der Unfalldaten
--
-- 11.12.2000 - 1.001 (1.002)
-- Symbolische Verweise integriert fr Automatische_Dauerzaehlstelle, manuelle_Zaehlstelle
-- Verlegung von oertliche_Zuordnung in das Schema Strassennetz
-- Verlegung von verwaltungstechn_Zuordnung in das Schema Administration
-- 
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE automat_Dauerzaehlstelle (
   automat_Dauerzaehlstelle_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (automat_Dauerzaehlstelle_ID) REFERENCES Strassennetz.Streckenobjekt_hist,
   FOREIGN KEY (automat_Dauerzaehlstelle_ID) REFERENCES autom_Dauerzaehlst_abstrakt,
   FOREIGN KEY (automat_Dauerzaehlstelle_ID) REFERENCES Verkehrsstaerke.Zaehlstelle,
   Name
      VARCHAR(50),
   hat_oertliche_Zuordnung
      INTEGER NOT NULL REFERENCES oertliche_Zuordnung_DZ,
   hat_verwaltungstechn_Zuordnung
      INTEGER NOT NULL REFERENCES verwaltungstechn_Zuordnung_DZ,
   hat_Erfassungstechnik
      INTEGER NOT NULL REFERENCES Erfassungstechnik,
   gehoert_zu_UZ_VRZ
      INTEGER REFERENCES Unterzentrale_Verkehrsrechnerz
)

CREATE TABLE autom_Dzst_hat_Zst_Nr (
   automat_Dauerzaehlstelle
      INTEGER NOT NULL REFERENCES automat_Dauerzaehlstelle,
   Zaehlstellennummer
      INTEGER NOT NULL REFERENCES Zaehlstellennummer
)

CREATE TABLE autom_Dzst_ist_K_in_Abl (
   automat_Dauerzaehlstelle
      INTEGER NOT NULL REFERENCES automat_Dauerzaehlstelle,
   Ableitung_autom_Dauerzaehlst
      INTEGER NOT NULL REFERENCES Ableitung_autom_Dauerzaehlst
)

CREATE TABLE autom_Dzst_zu_man_Zst (
   automat_Dauerzaehlstelle
      INTEGER NOT NULL REFERENCES automat_Dauerzaehlstelle,
   manuelle_Zaehlstelle_abstrakt
      INTEGER NOT NULL REFERENCES Manuelle_Zaehlstelle.manuelle_Zaehlstelle_abstrakt
)

CREATE TABLE autom_Dauerzaehlst_abstrakt (
   autom_Dauerzaehlst_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_autom_Dauerzaehlst_abstr
      INTEGER NOT NULL REFERENCES Art_autom_Dauerzaehlst_abstr
)

CREATE TABLE Art_autom_Dauerzaehlst_abstr (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(29) NOT NULL
)

INSERT INTO Art_autom_Dauerzaehlst_abstr VALUES ( 12001, 'automat_Dauerzaehlstelle' )
INSERT INTO Art_autom_Dauerzaehlst_abstr VALUES ( 12003, 'autom_Dauerzaehlst_Symbol' )

CREATE TABLE autom_Dauerzaehlst_Symbol (
   autom_Dauerzaehlst_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (autom_Dauerzaehlst_Symbol_ID) REFERENCES autom_Dauerzaehlst_abstrakt,
   Kennung
      CHAR(8) NOT NULL
)

CREATE TABLE Zaehlstellennummer (
   Zaehlstellennummer_ID
      INTEGER NOT NULL PRIMARY KEY,
   Nummer
      VARCHAR(8) NOT NULL,
   Art_Zaehlstellennummer
      INTEGER NOT NULL REFERENCES Art_Zaehlstellennummer
)

CREATE TABLE Art_Zaehlstellennummer (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Art_Zaehlstellennummer VALUES (1,'BASt-Nummer')
INSERT INTO Art_Zaehlstellennummer VALUES (2,'Landesnummer')
INSERT INTO Art_Zaehlstellennummer VALUES (3,'sonstige Nummer')

CREATE TABLE oertliche_Zuordnung_DZ (
   oertliche_Zuordnung_DZ_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (oertliche_Zuordnung_DZ_ID) REFERENCES Strassennetz.oertliche_Zuordnung
)

CREATE TABLE oertl_Zuordnung_DZ__h_Richtung (
   oertliche_Zuordnung_DZ
      INTEGER NOT NULL REFERENCES oertliche_Zuordnung_DZ,
   Richtungen
      INTEGER NOT NULL REFERENCES Richtungen
)

CREATE TABLE Richtungen (
   Richtungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Nahziel
      VARCHAR(50),
   Fernziel
      VARCHAR(50),
   Richtung
      INTEGER REFERENCES Himmelsrichtung,
   Bezugsrichtung
      CHAR(1) REFERENCES Strassennetz.Bezugsrichtung
)

CREATE TABLE Himmelsrichtung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Himmelsrichtung VALUES (1,'Norden')
INSERT INTO Himmelsrichtung VALUES (2,'Osten')
INSERT INTO Himmelsrichtung VALUES (3,'Sden')
INSERT INTO Himmelsrichtung VALUES (4,'Westen')

CREATE TABLE verwaltungstechn_Zuordnung_DZ (
   verwaltungstechn_Zuordng_DZ_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (verwaltungstechn_Zuordng_DZ_ID) REFERENCES Administration.verwaltungstechn_Zuordnung
)

CREATE TABLE Erfassungstechnik (
   Erfassungstechnik_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Zaehlgeraet
      INTEGER NOT NULL REFERENCES Zaehlgeraet
)

CREATE TABLE Zaehlgeraet (
   Zaehlgeraet_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Zaehlgeraet_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Hersteller
      VARCHAR(255) NOT NULL,
   Analyse_Software
      VARCHAR(255),
   Detektorart
      VARCHAR(255) NOT NULL
)

CREATE TABLE Zaehlgeraet__Art_d_Datenausg (
   Zaehlgeraet
      INTEGER NOT NULL REFERENCES Zaehlgeraet,
   Art_der_Datenausgabe
      VARCHAR(255) NOT NULL
)

CREATE TABLE Erfassungsmerkmale_DZ (
   Erfassungsmerkmale_DZ_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Erfassungsmerkmale_DZ_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Zaehlintervallaenge_in_Minuten
      INTEGER,
   Fahrzeugklassenunterscheidung
      INTEGER NOT NULL REFERENCES Logical_Types.Boolean,
   zu_Zaehlgeraet_DZ
      INTEGER NOT NULL REFERENCES Zaehlgeraet
)

CREATE TABLE Erfassmerkm_DZ__Art_d_reg_Dat (
   Erfassungsmerkmale_DZ
      INTEGER NOT NULL REFERENCES Erfassungsmerkmale_DZ,
   Art_der_registrierten_Daten
      VARCHAR(255) NOT NULL
)

CREATE TABLE Detektoren_DZ (
   Detektoren_DZ_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Detektoren_DZ_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   ist_Fahrstreifen_zugeordnet
      INTEGER NOT NULL REFERENCES Verkehr.Fahrstreifen_Nummer,
   von_Zaehlgeraet
      INTEGER NOT NULL REFERENCES Zaehlgeraet
)

CREATE TABLE Unterzentrale_Verkehrsrechnerz (
   Unterzentr_Verkehrsrechnerz_ID
      INTEGER NOT NULL PRIMARY KEY,
   Name
      VARCHAR(255)
)

CREATE TABLE Uz_Vrz__von_autom_Dauerzaehlst (
   Unterzentrale_Verkehrsrechnerz
      INTEGER NOT NULL REFERENCES Unterzentrale_Verkehrsrechnerz,
   autom_Dauerzaehlst_abstrakt
      INTEGER NOT NULL REFERENCES autom_Dauerzaehlst_abstrakt
)

CREATE TABLE abgeleitete_Dauerzaehlstelle (
   abgeleitete_Dauerzaehlst_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (abgeleitete_Dauerzaehlst_ID) REFERENCES Strassennetz.Streckenobjekt_hist,
   FOREIGN KEY (abgeleitete_Dauerzaehlst_ID) REFERENCES Verkehrsstaerke.Zaehlstelle,
   Name
      VARCHAR(255),
   hat_Zaehlstellennummer
      INTEGER NOT NULL REFERENCES Zaehlstellennummer
)

CREATE TABLE abgel_Dauerz__hat_Ableitung (
   abgeleitete_Dauerzaehlstelle
      INTEGER NOT NULL REFERENCES abgeleitete_Dauerzaehlstelle,
   Ableitung_DZ
      INTEGER NOT NULL REFERENCES Ableitung_DZ
)

CREATE TABLE abgel_Dauerz__hat_Richtungen (
   abgeleitete_Dauerzaehlstelle
      INTEGER NOT NULL REFERENCES abgeleitete_Dauerzaehlstelle,
   Richtungen
      INTEGER NOT NULL REFERENCES Richtungen
)

CREATE TABLE Ableitung_DZ (
   Ableitung_DZ_ID
      INTEGER NOT NULL PRIMARY KEY,
   Bezugsrichtung
      CHAR(1) NOT NULL REFERENCES Strassennetz.Bezugsrichtung
)

CREATE TABLE Ableitung_autom_Dauerzaehlst (
   Ableitg_autom_Dauerzaehlst_ID
      INTEGER NOT NULL PRIMARY KEY,
   Vorzeichen
      CHAR(1) NOT NULL REFERENCES Allgemeine_Objekte.Vorzeichen,
   automat_Dauerzaehlstelle
      INTEGER NOT NULL REFERENCES autom_Dauerzaehlst_abstrakt,
   Ableitung_DZ
      INTEGER NOT NULL REFERENCES Ableitung_DZ
)



CREATE SCHEMA Verkehrsstaerke

-- Historie:
--
-- 29.06.2004 - 1.005 (1.009)
-- Krzung von Bezeichnern, vernderte Schlssel (SQL)
--
-- 03.09.2003 - 1.004 (1.008)
-- berarbeitung gem N0049
--
-- 31.05.2002 - 1.003 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 12.09.2001 - 1.002 (1.004)
-- formale Versionierung durch Versionierung Verkehrsstaerke:
-- Bezug zum Unfall hergestellt nach berarbeitung der Unfalldaten
--
-- 11.12.2000 - 1.001 (1.002)
-- Symbolische Verweise integriert fr Automatische_Dauerzaehlstelle, manuelle_Zaehlstelle
-- Verlegung von oertliche_Zuordnung in das Schema Strassennetz
-- Verlegung von verwaltungstechn_Zuordnung in das Schema Administration
-- 
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE DTV (
   DTV_ID
      INTEGER NOT NULL PRIMARY KEY,
   Fahrzeuge_pro_24h
      INTEGER NOT NULL,
   Bezugsjahr
      INTEGER NOT NULL, -- Jahr
   Bezugsmonat
      INTEGER, -- Monat
   CHECK ( ( Bezugsmonat >= 1 ) AND ( Bezugsmonat <= 12 ) ),
   Fahrzeugkollektiv
      INTEGER NOT NULL REFERENCES Fahrzeugkollektiv,
   Tagesgruppe
      INTEGER NOT NULL REFERENCES Tagesgruppe,
   Zaehltage
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Zaehltage >= 0 ),
   Gesamtstunden
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Gesamtstunden >= 0 ),
   Schaetzwert
      INTEGER NOT NULL REFERENCES Logical_Types.Boolean,
   fuer_Fahrstreifen
      INTEGER REFERENCES Verkehr.Fahrstreifen_Nummer,
   hat_Bezugsrichtung
      CHAR(1) REFERENCES Strassennetz.Bezugsrichtung,
   aus_Zaehlstelle
      INTEGER NOT NULL REFERENCES Zaehlstelle_abstrakt
)

CREATE TABLE MSV (
   MSV_ID
      INTEGER NOT NULL PRIMARY KEY,
   Fahrzeuge_pro_h
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Fahrzeuge_pro_h >= 0 ),
   Bezugsjahr
      INTEGER NOT NULL, -- Jahr
   Tagesgruppe
      INTEGER NOT NULL REFERENCES Tagesgruppe,
   hat_Bezugsrichtung
      CHAR(1) NOT NULL REFERENCES Strassennetz.Bezugsrichtung,
   aus_Zaehlstelle
      INTEGER NOT NULL REFERENCES Zaehlstelle_abstrakt
)

CREATE TABLE MSV__hat_Anteil_am_DTV (
   MSV
      INTEGER NOT NULL REFERENCES MSV,
   Anteil_am_DTV
      INTEGER NOT NULL REFERENCES Anteil_am_DTV
)

CREATE TABLE Anteil_am_DTV (
   Anteil_am_DTV_ID
      INTEGER NOT NULL PRIMARY KEY,
   Anteil
      REAL NOT NULL, -- Prozent
   Fahrzeuggruppe
      INTEGER NOT NULL REFERENCES Fahrzeuggruppe
)

CREATE TABLE Fahrzeugkollektiv (
   Kennung
      INTEGER NOT NULL PRIMARY KEY
)

INSERT INTO Fahrzeugkollektiv VALUES (101)
INSERT INTO Fahrzeugkollektiv VALUES (102)
INSERT INTO Fahrzeugkollektiv VALUES (103)
INSERT INTO Fahrzeugkollektiv VALUES (104)
INSERT INTO Fahrzeugkollektiv VALUES (105)
INSERT INTO Fahrzeugkollektiv VALUES (106)
INSERT INTO Fahrzeugkollektiv VALUES (107)
INSERT INTO Fahrzeugkollektiv VALUES (108)
INSERT INTO Fahrzeugkollektiv VALUES (109)
INSERT INTO Fahrzeugkollektiv VALUES (110)
INSERT INTO Fahrzeugkollektiv VALUES (111)
INSERT INTO Fahrzeugkollektiv VALUES (112)
INSERT INTO Fahrzeugkollektiv VALUES (113)
INSERT INTO Fahrzeugkollektiv VALUES (114)
INSERT INTO Fahrzeugkollektiv VALUES (201)
INSERT INTO Fahrzeugkollektiv VALUES (202)
INSERT INTO Fahrzeugkollektiv VALUES (203)
INSERT INTO Fahrzeugkollektiv VALUES (204)

CREATE TABLE Fahrzeugart (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Kennung) REFERENCES Fahrzeugkollektiv,
   Kennung_Str
      CHAR(12) NOT NULL,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Fahrzeugart VALUES (101,'nk Kfz','nicht klassifizierbare Fahrzeuge (Sonstige)')
INSERT INTO Fahrzeugart VALUES (102,'Krad','Motorrder')
INSERT INTO Fahrzeugart VALUES (103,'Pkw(grund)','Pkw')
INSERT INTO Fahrzeugart VALUES (104,'Lfw','Lieferwagen')
INSERT INTO Fahrzeugart VALUES (105,'Pkw','Krad + Pkw(grund) + Lfw')
INSERT INTO Fahrzeugart VALUES (106,'Pkw','Pkw + nk Kfz')
INSERT INTO Fahrzeugart VALUES (107,'PkwA','Pkw und Lfw mit Anhnger')
INSERT INTO Fahrzeugart VALUES (108,'Lkw','Lkw mit einem zulssigen Gesamtgewicht von mehr als 3,5 t')
INSERT INTO Fahrzeugart VALUES (109,'LkwA(grund)','Lkw mit Anhnger')
INSERT INTO Fahrzeugart VALUES (110,'Sattel-Kfz','Sattelkraftfahrzeuge')
INSERT INTO Fahrzeugart VALUES (111,'LkwA','LkwA(grund) + Sattel-Kfz')
INSERT INTO Fahrzeugart VALUES (112,'Bus','Busse mit mehr als 9 Sitzpltzen')
INSERT INTO Fahrzeugart VALUES (113,'Lkw','PkwA + Lkw + LkwA + Bus')
INSERT INTO Fahrzeugart VALUES (114,'Kfz','Pkw + Lkw')

CREATE TABLE Fahrzeuggruppe (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Kennung) REFERENCES Fahrzeugkollektiv,
   Kennung_Str
      CHAR(12) NOT NULL,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Fahrzeuggruppe VALUES (201,'PV','motorisierte Zweirder, Pkw, Busse')
INSERT INTO Fahrzeuggruppe VALUES (202,'GV','Lieferwagen, Lkw ohne Anhnger, Lastzge')
INSERT INTO Fahrzeuggruppe VALUES (203,'SV','Busse, Lkw ohne Anhnger, Lastzge')
INSERT INTO Fahrzeuggruppe VALUES (204,'KFZ','PV + GV')

CREATE TABLE Tagesgruppe (
   Kennung
      INTEGER NOT NULL PRIMARY KEY
)

INSERT INTO Tagesgruppe VALUES (11)
INSERT INTO Tagesgruppe VALUES (12)
INSERT INTO Tagesgruppe VALUES (13)
INSERT INTO Tagesgruppe VALUES (21)
INSERT INTO Tagesgruppe VALUES (22)
INSERT INTO Tagesgruppe VALUES (23)
INSERT INTO Tagesgruppe VALUES (24)
INSERT INTO Tagesgruppe VALUES (25)
INSERT INTO Tagesgruppe VALUES (31)

CREATE TABLE Fahrtzweckgruppe (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Kennung) REFERENCES Tagesgruppe,
   Kennung_Str
      CHAR(9) NOT NULL,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Fahrtzweckgruppe VALUES (11,'W','Werktage')
INSERT INTO Fahrtzweckgruppe VALUES (12,'U','Urlaubswerktage')
INSERT INTO Fahrtzweckgruppe VALUES (13,'S','Sonn- und Feiertage')

CREATE TABLE Normalzeitbereich (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Kennung) REFERENCES Tagesgruppe,
   Kennung_Str
      CHAR(9) NOT NULL,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Normalzeitbereich VALUES (21,'Mo','Montag')
INSERT INTO Normalzeitbereich VALUES (22,'Di-Do','Dienstag-Donnerstag')
INSERT INTO Normalzeitbereich VALUES (23,'Fr','Freitag')
INSERT INTO Normalzeitbereich VALUES (24,'Sa','Samstag')
INSERT INTO Normalzeitbereich VALUES (25,'So','Sonntag')

CREATE TABLE weitere_Tagesgruppen (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Kennung) REFERENCES Tagesgruppe,
   Kennung_Str
      CHAR(9) NOT NULL,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO weitere_Tagesgruppen VALUES (31,'alle Tage','alle Tage')

CREATE TABLE Zaehlstelle (
   Zaehlstelle_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Zaehlstelle_ID) REFERENCES Zaehlstelle_abstrakt
)

CREATE TABLE Zaehlstelle__zu_DTV (
   Zaehlstelle
      INTEGER NOT NULL REFERENCES Zaehlstelle,
   DTV
      INTEGER NOT NULL REFERENCES DTV
)

CREATE TABLE Zaehlstelle__zu_MSV (
   Zaehlstelle
      INTEGER NOT NULL REFERENCES Zaehlstelle,
   MSV
      INTEGER NOT NULL REFERENCES MSV
)

CREATE TABLE Zaehlst__z_Kennw_z_Laermber (
   Zaehlstelle
      INTEGER NOT NULL REFERENCES Zaehlstelle,
   Kennwert_zur_Laermberechnung
      INTEGER NOT NULL REFERENCES Kennwert_zur_Laermberechnung
)

CREATE TABLE Zaehlstelle__zu_Jahresgangltyp (
   Zaehlstelle
      INTEGER NOT NULL REFERENCES Zaehlstelle,
   Jahresganglinientyp
      INTEGER NOT NULL REFERENCES Jahresganglinientyp
)

CREATE TABLE Zaehlstelle__zu_Wochengangltyp (
   Zaehlstelle
      INTEGER NOT NULL REFERENCES Zaehlstelle,
   Wochenganglinientyp
      INTEGER NOT NULL REFERENCES Wochenganglinientyp
)

CREATE TABLE Zaehlstelle__zu_Tagesgangltyp (
   Zaehlstelle
      INTEGER NOT NULL REFERENCES Zaehlstelle,
   Tagesganglinientyp
      INTEGER NOT NULL REFERENCES Tagesganglinientyp
)

CREATE TABLE Zaehlstelle_abstrakt (
   Zaehlstelle_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_Zaehlstelle_abstrakt
      INTEGER NOT NULL REFERENCES Art_Zaehlstelle_abstrakt
)

CREATE TABLE Art_Zaehlstelle_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(29) NOT NULL
)

INSERT INTO Art_Zaehlstelle_abstrakt VALUES ( 12001, 'automat_Dauerzaehlstelle' )
INSERT INTO Art_Zaehlstelle_abstrakt VALUES ( 12015, 'abgeleitete_Dauerzaehlstelle' )
INSERT INTO Art_Zaehlstelle_abstrakt VALUES ( 13013, 'Zaehlstelle_Symbol' )
INSERT INTO Art_Zaehlstelle_abstrakt VALUES ( 17001, 'manuelle_Zaehlstelle_SVZ' )

CREATE TABLE Zaehlstelle_Symbol (
   Zaehlstelle_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Zaehlstelle_Symbol_ID) REFERENCES Zaehlstelle_abstrakt,
   Kennung
      VARCHAR(8) NOT NULL
)

CREATE TABLE Kennwert_zur_Laermberechnung (
   Kennwert_zur_Laermberechn_ID
      INTEGER NOT NULL PRIMARY KEY,
   Stundengruppe
      CHAR(5) NOT NULL REFERENCES Stundengruppe,
   Kraftfahrzeuge_pro_h
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Kraftfahrzeuge_pro_h >= 0 ),
   Bezugsjahr
      INTEGER NOT NULL, -- Jahr
   aus_Zaehlstelle
      INTEGER NOT NULL REFERENCES Zaehlstelle_abstrakt
)

CREATE TABLE Kennw_z_Laermber__h_Ant_Kennw (
   Kennwert_zur_Laermberechnung
      INTEGER NOT NULL REFERENCES Kennwert_zur_Laermberechnung,
   Anteil_Kennwert
      INTEGER NOT NULL REFERENCES Anteil_Kennwert
)

CREATE TABLE Stundengruppe (
   Kennung
      CHAR(5) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Stundengruppe VALUES ('Tag','Tag (6h-22h)')
INSERT INTO Stundengruppe VALUES ('Nacht','Nacht (22h-6h)')

CREATE TABLE Anteil_Kennwert (
   Anteil_Kennwert_ID
      INTEGER NOT NULL PRIMARY KEY,
   Anteil
      REAL NOT NULL, -- Prozent
   Fahrzeuggruppe
      INTEGER NOT NULL REFERENCES Fahrzeuggruppe
)

CREATE TABLE Jahresganglinientyp (
   Jahresganglinientyp_ID
      INTEGER NOT NULL PRIMARY KEY,
   Bezugsjahr
      INTEGER NOT NULL, -- Jahr
   Typ
      CHAR(1) NOT NULL REFERENCES Typ_Jahresganglinie,
   aus_Zaehlstelle
      INTEGER NOT NULL REFERENCES Zaehlstelle_abstrakt
)

CREATE TABLE Typ_Jahresganglinie (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Typ_Jahresganglinie VALUES ('A','Weitgehend ausgeglichene Ganglinie mit Rckgngen fr Ferien- und Feiertagswochen.')
INSERT INTO Typ_Jahresganglinie VALUES ('B','Weitgehend ausgeglichene Ganglinie, im Sommerhalbjahr etwas strkerer Verkehr als im Winterhalbjahr.')
INSERT INTO Typ_Jahresganglinie VALUES ('C','Im Sommerhalbjahr sichtbar strkerer Verkehr als im Winterhalbjahr.')
INSERT INTO Typ_Jahresganglinie VALUES ('D','Spitzen fr Ferien- und Feiertagswochen.')
INSERT INTO Typ_Jahresganglinie VALUES ('E','Wie Typ D, jedoch gleichmiger Verkehrsanstieg im 1. Halbjahr.')
INSERT INTO Typ_Jahresganglinie VALUES ('F','Spitzen fr Feiertagswochen und deutliche Spitzen fr Ferienwochen.')

CREATE TABLE Wochenganglinientyp (
   Wochenganglinientyp_ID
      INTEGER NOT NULL PRIMARY KEY,
   Bezugsjahr
      INTEGER NOT NULL, -- Jahr
   Typ
      CHAR(1) NOT NULL REFERENCES Typ_Wochenganglinie,
   Bezugsrichtung
      CHAR(1) NOT NULL REFERENCES Strassennetz.Bezugsrichtung,
   aus_Zaehlstelle
      INTEGER NOT NULL REFERENCES Zaehlstelle
)

CREATE TABLE Typ_Wochenganglinie (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Typ_Wochenganglinie VALUES ('A','Wochenende stark abfallend, ausgeprgtes Minimum Sonntag.')
INSERT INTO Typ_Wochenganglinie VALUES ('B','Wochenende stark abfallend, Minimum Sonntag.')
INSERT INTO Typ_Wochenganglinie VALUES ('C','Maximum Freitag, Wochenende abfallend.')
INSERT INTO Typ_Wochenganglinie VALUES ('D','(Lokales) Maximum Montag, Freitag, Sonntag, Minimum Samstag.')
INSERT INTO Typ_Wochenganglinie VALUES ('E','Maximum Freitag, Samstag berdurchschnittlich.')
INSERT INTO Typ_Wochenganglinie VALUES ('F','Ausgeprgtes Maximum Sonntag.')

CREATE TABLE Tagesganglinientyp (
   Tagesganglinientyp_ID
      INTEGER NOT NULL PRIMARY KEY,
   Bezugsjahr
      INTEGER NOT NULL, -- Jahr
   Typ
      INTEGER NOT NULL REFERENCES Tagesgruppe_Typ,
   Bezugsrichtung
      CHAR(1) NOT NULL REFERENCES Strassennetz.Bezugsrichtung,
   aus_Zaehlstelle
      INTEGER NOT NULL REFERENCES Zaehlstelle
)

CREATE TABLE Tagesganglinientyp__Stundenind (
   Tagesganglinientyp
      INTEGER NOT NULL REFERENCES Tagesganglinientyp,
   Stundenindex
      INTEGER NOT NULL
)

CREATE TABLE Tagesgruppe_Typ (
   Tagesgruppe_Typ_ID
      INTEGER NOT NULL PRIMARY KEY,
   Tagesgruppe
      VARCHAR(7) NOT NULL,
   Buchstabe
      CHAR(1) NOT NULL,
   Langtext
      VARCHAR(255) NOT NULL,
   UNIQUE ( Tagesgruppe , Buchstabe ) 
)

INSERT INTO Tagesgruppe_Typ VALUES (11,'Montag','A','Stark ausgeprgte Morgenspitze.')
INSERT INTO Tagesgruppe_Typ VALUES (12,'Montag','B','Morgenspitze, geringe Nachmittagsspitze.')
INSERT INTO Tagesgruppe_Typ VALUES (13,'Montag','C','Relativ ausgeglichene Verkehrsverteilung tagsber.')
INSERT INTO Tagesgruppe_Typ VALUES (14,'Montag','D','Doppelspitze (Morgen / Nachmittag).')
INSERT INTO Tagesgruppe_Typ VALUES (15,'Montag','E','Nachmittagsspitze, geringe Morgenspitze')
INSERT INTO Tagesgruppe_Typ VALUES (16,'Montag','F','Stark ausgeprgte Nachmittagsspitze.')
INSERT INTO Tagesgruppe_Typ VALUES (17,'Montag','G','berdurchschnittliche Anteilswerte frhmorgens, nach Morgenspitze stetig abfallend.')
INSERT INTO Tagesgruppe_Typ VALUES (21,'Di - Do','A','Stark ausgeprgte Morgenspitze.')
INSERT INTO Tagesgruppe_Typ VALUES (22,'Di - Do','B','Morgenspitze, geringe Nachmittagsspitze.')
INSERT INTO Tagesgruppe_Typ VALUES (23,'Di - Do','C','Relativ ausgeglichene Verkehrsverteilung tagsber.')
INSERT INTO Tagesgruppe_Typ VALUES (24,'Di - Do','D','Doppelspitze (Morgen / Nachmittag).')
INSERT INTO Tagesgruppe_Typ VALUES (25,'Di - Do','E','Nachmittagsspitze, geringe Morgenspitze.')
INSERT INTO Tagesgruppe_Typ VALUES (26,'Di - Do','F','Stark ausgeprgte Nachmittagsspitze.')
INSERT INTO Tagesgruppe_Typ VALUES (31,'Freitag','A','Stark ausgeprgte Morgenspitze.')
INSERT INTO Tagesgruppe_Typ VALUES (32,'Freitag','B','Morgenspitze, gegenber Mittag hhere Verkehrsstrken nachmittags.')
INSERT INTO Tagesgruppe_Typ VALUES (33,'Freitag','C','Relativ ausgeglichene Verkehrsverteilung tagsber.')
INSERT INTO Tagesgruppe_Typ VALUES (34,'Freitag','D','Morgenspitze, breites Maximum am Nachmittag.')
INSERT INTO Tagesgruppe_Typ VALUES (35,'Freitag','E','Breites Maximum am Nachmittag.')
INSERT INTO Tagesgruppe_Typ VALUES (36,'Freitag','F','Stark ausgeprgtes, breites Maximum am Nachmittag.')
INSERT INTO Tagesgruppe_Typ VALUES (41,'Samstag','A','Relativ ausgeglichene Verkehrsverteilung tagsber.')
INSERT INTO Tagesgruppe_Typ VALUES (42,'Samstag','B','Nach Vormittagsspitze stetig abfallend.')
INSERT INTO Tagesgruppe_Typ VALUES (43,'Samstag','C','Doppelspitze (Vormittag / Nachmittag).')
INSERT INTO Tagesgruppe_Typ VALUES (44,'Samstag','D','Breite Nachmittagsspitze.')
INSERT INTO Tagesgruppe_Typ VALUES (45,'Samstag','E','Abendspitze.')
INSERT INTO Tagesgruppe_Typ VALUES (46,'Samstag','F','Nach ausgeprgter Vormittagsspitze stetig abfallend.')
INSERT INTO Tagesgruppe_Typ VALUES (47,'Samstag','G','Stetig ansteigend zu ausgeprgter Nachmittagsspitze, danach stetig fallend.')
INSERT INTO Tagesgruppe_Typ VALUES (48,'Samstag','H','Stark ausgeprgte Abendspitze.')
INSERT INTO Tagesgruppe_Typ VALUES (51,'Sonntag','A','Relativ ausgeglichene Verkehrsverteilung tagsber.')
INSERT INTO Tagesgruppe_Typ VALUES (52,'Sonntag','B','Mittagsspitze.')
INSERT INTO Tagesgruppe_Typ VALUES (53,'Sonntag','C','Nachmittagsspitze.')
INSERT INTO Tagesgruppe_Typ VALUES (54,'Sonntag','D','Abendspitze.')
INSERT INTO Tagesgruppe_Typ VALUES (55,'Sonntag','E','Ausgeprgte Mittagsspitze.')
INSERT INTO Tagesgruppe_Typ VALUES (56,'Sonntag','F','Ausgeprgte Nachmittagsspitze.')
INSERT INTO Tagesgruppe_Typ VALUES (57,'Sonntag','G','Ausgeprgte Abendspitze.')



CREATE SCHEMA Erfassung_Geschwindigkeiten

-- Historie:
--
-- 29.06.2004 - 1.005 (1.009)
-- Krzung von Bezeichnern, vernderte Schlssel (SQL)
--
-- 03.09.2003 - 1.004 (1.008)
-- berarbeitung gem N0049
--
-- 31.05.2002 - 1.003 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 12.09.2001 - 1.002 (1.004)
-- formale Versionierung durch Versionierung Verkehrsstaerke:
-- Bezug zum Unfall hergestellt nach berarbeitung der Unfalldaten
--
-- 11.12.2000 - 1.001 (1.002)
-- Symbolische Verweise integriert fr Automatische_Dauerzaehlstelle, manuelle_Zaehlstelle
-- Verlegung von oertliche_Zuordnung in das Schema Strassennetz
-- Verlegung von verwaltungstechn_Zuordnung in das Schema Administration
-- 
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Erfassung_Geschwindigkeiten (
   Erfassung_Geschwindigkeiten_ID
      INTEGER NOT NULL PRIMARY KEY,
   zugehoerige_Fahrzeugklasse
      INTEGER NOT NULL
)

CREATE TABLE Erf_Geschw__hat_V_Verteilungen (
   Erfassung_Geschwindigkeiten
      INTEGER NOT NULL REFERENCES Erfassung_Geschwindigkeiten,
   V_Verteilungen
      INTEGER NOT NULL REFERENCES V_Verteilungen
)

CREATE TABLE Erf_Geschw__hat_aggreg_Werte (
   Erfassung_Geschwindigkeiten
      INTEGER NOT NULL REFERENCES Erfassung_Geschwindigkeiten,
   aggregierte_Werte
      INTEGER NOT NULL REFERENCES aggregierte_Werte
)

CREATE TABLE V_Verteilungen (
   V_Verteilungen_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE V_Verteilung__hat_Anzahl_V_Kl (
   V_Verteilungen
      INTEGER NOT NULL REFERENCES V_Verteilungen,
   Anzahl_V_Klassen
      INTEGER NOT NULL REFERENCES Anzahl_V_Klassen
)

CREATE TABLE V_Verteilungen__hat_V_Klassen (
   V_Verteilungen
      INTEGER NOT NULL REFERENCES V_Verteilungen,
   V_Klassen
      INTEGER NOT NULL REFERENCES V_Klassen
)

CREATE TABLE Anzahl_V_Klassen (
   Anzahl_V_Klassen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Fahrzeugklasse
      INTEGER NOT NULL,
   Anzahl_V_Klassen
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Anzahl_V_Klassen >= 0 ),
   CHECK ( Anzahl_V_Klassen <= 16 ),
   CHECK ( Fahrzeugklasse >= 1 )
)

CREATE TABLE V_Klassen (
   V_Klassen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Klassennummer
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Klassennummer >= 0 ) AND ( Klassennummer <= 99 ) ),
   Klassengrenze
      INTEGER NOT NULL,
   Klassenwert
      INTEGER NOT NULL
)

CREATE TABLE V_Kl__hat_abgel_Wert_u_Verteil (
   V_Klassen
      INTEGER NOT NULL REFERENCES V_Klassen,
   abgel_Werte_u_Verteilgen_VK
      INTEGER NOT NULL REFERENCES abgel_Werte_u_Verteilgen_VK
)

CREATE TABLE abgel_Werte_u_Verteilgen_VK (
   abgel_Werte_u_Verteilgen_VK_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE aggregierte_Werte (
   aggregierte_Werte_ID
      INTEGER NOT NULL PRIMARY KEY,
   Standardabweichung
      INTEGER, -- Stundenkilometer
   CHECK ( Standardabweichung >= 0 ),
   v85
      INTEGER, -- Stundenkilometer
   CHECK ( v85 >= 0 ),
   hat_mittlere_Geschwindigkeit
      INTEGER NOT NULL REFERENCES mittlere_Geschwindigkeit,
   CHECK ( v85 <= 254 ),
   CHECK ( Standardabweichung <= 255 )
)

CREATE TABLE mittlere_Geschwindigkeit (
   mittlere_Geschwindigkeit_ID
      INTEGER NOT NULL PRIMARY KEY,
   Geschwindigkeit
      INTEGER NOT NULL, -- Stundenkilometer
   CHECK ( Geschwindigkeit >= 0 ),
   CHECK ( Geschwindigkeit <= 255 )
)

CREATE TABLE mittl_Geschw__hat_abgel_Werte (
   mittlere_Geschwindigkeit
      INTEGER NOT NULL REFERENCES mittlere_Geschwindigkeit,
   abgeleitete_Werte_VM
      INTEGER NOT NULL REFERENCES abgeleitete_Werte_VM
)

CREATE TABLE abgeleitete_Werte_VM (
   abgeleitete_Werte_VM_ID
      INTEGER NOT NULL PRIMARY KEY
)



CREATE SCHEMA Achslastdaten

-- Historie:
--
-- 29.06.2004 - 1.005 (1.009)
-- Krzung von Bezeichnern, vernderte Schlssel (SQL)
--
-- 03.09.2003 - 1.004 (1.008)
-- berarbeitung gem N0049
--
-- 31.05.2002 - 1.003 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 12.09.2001 - 1.002 (1.004)
-- formale Versionierung durch Versionierung Verkehrsstaerke:
-- Bezug zum Unfall hergestellt nach berarbeitung der Unfalldaten
--
-- 11.12.2000 - 1.001 (1.002)
-- Symbolische Verweise integriert fr Automatische_Dauerzaehlstelle, manuelle_Zaehlstelle
-- Verlegung von oertliche_Zuordnung in das Schema Strassennetz
-- Verlegung von verwaltungstechn_Zuordnung in das Schema Administration
-- 
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Achslastdatenerfassung (
   Achslastdatenerfassung_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Achsldaterf__hat_GG_Vert_Fz_Kl (
   Achslastdatenerfassung
      INTEGER NOT NULL REFERENCES Achslastdatenerfassung,
   GG_Verteilung_einer_FZ_Klasse
      INTEGER NOT NULL REFERENCES GG_Verteilung_einer_FZ_Klasse
)

CREATE TABLE Achsldaterf__hat_Achslvrt_Atyp (
   Achslastdatenerfassung
      INTEGER NOT NULL REFERENCES Achslastdatenerfassung,
   Achslastverteilung_e_Achstyps
      INTEGER NOT NULL REFERENCES Achslastverteilung_e_Achstyps
)

CREATE TABLE Achsldaterf__hat_abgel_W_u_V (
   Achslastdatenerfassung
      INTEGER NOT NULL REFERENCES Achslastdatenerfassung,
   abgel_Werte_und_Verteilungen
      INTEGER NOT NULL REFERENCES abgel_Werte_und_Verteilungen
)

CREATE TABLE abgel_Werte_und_Verteilungen (
   abgel_Werte_u_Verteilungen_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE GG_Verteilung_einer_FZ_Klasse (
   GG_Verteilg_einer_FZ_Klasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   Fahrzeugklasse
      INTEGER NOT NULL,
   Anzahl_der_GG_Klassen_FZ_Kl_3
      INTEGER NOT NULL,
   Anzahl_der_GG_Klassen_FZ_Kl_4
      INTEGER NOT NULL,
   Anzahl_der_GG_Klassen_FZ_Kl_5
      INTEGER NOT NULL,
   Anzahl_Ueberladungen
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Anzahl_Ueberladungen >= 0 ),
   CHECK ( Anzahl_Ueberladungen<=255 ),
   CHECK ( ( Fahrzeugklasse >= 3 ) AND ( Fahrzeugklasse <= 5 ) )
)

CREATE TABLE GG_Vert_Fz_Kl__hat_GG_Klasse (
   GG_Verteilung_einer_FZ_Klasse
      INTEGER NOT NULL REFERENCES GG_Verteilung_einer_FZ_Klasse,
   GG_Klasse
      INTEGER NOT NULL REFERENCES GG_Klasse
)

CREATE TABLE GG_Klasse (
   GG_Klasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   Klassennummer
      INTEGER NOT NULL,
   Klassengrenze
      REAL NOT NULL, -- Groesse
   CHECK ( Klassengrenze >= 0 ),
   Klassenwert
      INTEGER NOT NULL, -- Klassenwert
   CHECK ( Klassenwert <= 65535 ),
   CHECK ( Klassenwert >= 0 ),
   CHECK ( ( Klassennummer >= 1 ) AND ( Klassennummer <= 8 ) )
)

CREATE TABLE Achstyp (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Achstyp VALUES (1,'Einfachachse')
INSERT INTO Achstyp VALUES (2,'Doppelachse')
INSERT INTO Achstyp VALUES (3,'Dreifachachse')

CREATE TABLE Achslastverteilung_e_Achstyps (
   Achslastverteilg_e_Achstype_ID
      INTEGER NOT NULL PRIMARY KEY,
   Achstyp
      INTEGER NOT NULL REFERENCES Achstyp,
   Anz_d_Klassen_f_Einzelachsen
      INTEGER NOT NULL, -- Anzahl_Klassen
   CHECK ( ( Anz_d_Klassen_f_Einzelachsen >= 1 ) AND ( Anz_d_Klassen_f_Einzelachsen <= 99 ) ),
   Anz_d_Klassen_f_Doppelachsen
      INTEGER NOT NULL, -- Anzahl_Klassen
   CHECK ( ( Anz_d_Klassen_f_Doppelachsen >= 1 ) AND ( Anz_d_Klassen_f_Doppelachsen <= 99 ) ),
   Anz_d_Klassen_f_Dreifachachsen
      INTEGER NOT NULL, -- Anzahl_Klassen
   CHECK ( ( Anz_d_Klassen_f_Dreifachachsen >= 1 ) AND ( Anz_d_Klassen_f_Dreifachachsen <= 99 ) ),
   hat_Klasse_AL
      INTEGER NOT NULL REFERENCES Klasse_AL
)

CREATE TABLE Klasse_AL (
   Klasse_AL_ID
      INTEGER NOT NULL PRIMARY KEY,
   Klassennummer
      INTEGER NOT NULL,
   Klassengrenze
      REAL NOT NULL, -- Groesse
   CHECK ( Klassengrenze >= 0 ),
   Klassenwert
      INTEGER NOT NULL, -- Klassenwert
   CHECK ( Klassenwert <= 65535 ),
   CHECK ( Klassenwert >= 0 ),
   CHECK ( ( Klassennummer >= 0 ) AND ( Klassennummer <= 99 ) )
)



CREATE SCHEMA Einzelfahrzeugdaten

-- Historie:
--
-- 29.06.2004 - 1.005 (1.009)
-- Krzung von Bezeichnern, vernderte Schlssel (SQL)
--
-- 03.09.2003 - 1.004 (1.008)
-- berarbeitung gem N0049
--
-- 31.05.2002 - 1.003 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 12.09.2001 - 1.002 (1.004)
-- formale Versionierung durch Versionierung Verkehrsstaerke:
-- Bezug zum Unfall hergestellt nach berarbeitung der Unfalldaten
--
-- 11.12.2000 - 1.001 (1.002)
-- Symbolische Verweise integriert fr Automatische_Dauerzaehlstelle, manuelle_Zaehlstelle
-- Verlegung von oertliche_Zuordnung in das Schema Strassennetz
-- Verlegung von verwaltungstechn_Zuordnung in das Schema Administration
-- 
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Einzelfahrzeugdatenerfassung (
   Einzelfahrzeugdatenerfassg_ID
      INTEGER NOT NULL PRIMARY KEY,
   Nettozeitluecke_z_vorherig_FZ
      INTEGER, -- Millisekunden
   CHECK ( Nettozeitluecke_z_vorherig_FZ >= 0 ),
   Geschwindigkeit
      INTEGER NOT NULL, -- Stundenkilometer
   CHECK ( Geschwindigkeit >= 0 ),
   Fahrzeuglaenge
      REAL, -- Zentimeter
   CHECK ( Fahrzeuglaenge >= 0 ),
   Abstand_zum_vorausfahrenden_FZ
      REAL, -- Zentimeter
   CHECK ( Abstand_zum_vorausfahrenden_FZ >= 0 ),
   hat_zugehoerige_Fahrzeugklasse
      INTEGER NOT NULL REFERENCES zugehoerige_Fahrzeugklasse,
   hat_zugehoerigen_Zeitpunkt
      INTEGER NOT NULL REFERENCES zugehoeriger_Zeitpunkt,
   hat_fahrzeugbez_Achslastdaten
      INTEGER REFERENCES fahrzeugbezogene_Achslastdaten,
   CHECK ( Geschwindigkeit <= 255 )
)

CREATE TABLE Einzfzdaterf__hat_achsbez_Dat (
   Einzelfahrzeugdatenerfassung
      INTEGER NOT NULL REFERENCES Einzelfahrzeugdatenerfassung,
   achsbezogene_Daten
      INTEGER NOT NULL REFERENCES achsbezogene_Daten
)

CREATE TABLE zugehoerige_Fahrzeugklasse (
   zugehoerige_Fahrzeugklasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   Klasse
      VARCHAR(20) NOT NULL,
   Typ
      VARCHAR(20) NOT NULL
)

CREATE TABLE zugehoeriger_Zeitpunkt (
   zugehoeriger_Zeitpunkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Datum
      CHAR(10) NOT NULL, -- Datum
   CHECK ( Datum LIKE '__.__.____' ),
   Uhrzeit
      VARCHAR(12) NOT NULL, -- Uhrzeit
   CHECK ( ( Uhrzeit LIKE '__:__' ) OR ( Uhrzeit LIKE '__:__:__' ) OR ( Uhrzeit LIKE '__:__:__:___' ) )
)

CREATE TABLE fahrzeugbezogene_Achslastdaten (
   fahrzeugbezog_Achslastdaten_ID
      INTEGER NOT NULL PRIMARY KEY,
   Anzahl_der_Achsen
      INTEGER NOT NULL, -- Anzahl
   CHECK ( Anzahl_der_Achsen >= 0 ),
   Gesamtgewicht
      REAL NOT NULL, -- Kilogramm
   CHECK ( Gesamtgewicht >= 0 ),
   hat_Ueberladung
      INTEGER NOT NULL REFERENCES Ueberladung
)

CREATE TABLE Ueberladung (
   Ueberladung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Ueberladung_vorhanden
      INTEGER REFERENCES Logical_Types.Boolean,
   Ueberladung
      REAL, -- Kilogramm
   CHECK ( Ueberladung >= 0 )
)

CREATE TABLE achsbezogene_Daten (
   achsbezogene_Daten_ID
      INTEGER NOT NULL PRIMARY KEY,
   Achsabstand_zur_Vorderachse
      REAL NOT NULL, -- Zentimeter
   CHECK ( Achsabstand_zur_Vorderachse >= 0 ),
   Achslast
      REAL NOT NULL, -- Kilogramm
   CHECK ( Achslast >= 0 ),
   Achstyp
      INTEGER NOT NULL REFERENCES Achslastdaten.Achstyp,
   hat_Ueberladung
      INTEGER NOT NULL REFERENCES Ueberladung
)



CREATE SCHEMA Manuelle_Zaehlstelle

-- Historie:
--
-- 29.06.2004 - 1.005 (1.009)
-- Krzung von Bezeichnern, vernderte Schlssel (SQL)
--
-- 03.09.2003 - 1.004 (1.008)
-- berarbeitung gem N0049
--
-- 31.05.2002 - 1.003 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 12.09.2001 - 1.002 (1.004)
-- formale Versionierung durch Versionierung Verkehrsstaerke:
-- Bezug zum Unfall hergestellt nach berarbeitung der Unfalldaten
--
-- 11.12.2000 - 1.001 (1.002)
-- Symbolische Verweise integriert fr Automatische_Dauerzaehlstelle, manuelle_Zaehlstelle
-- Verlegung von oertliche_Zuordnung in das Schema Strassennetz
-- Verlegung von verwaltungstechn_Zuordnung in das Schema Administration
-- 
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE manuelle_Zaehlstelle_SVZ (
   manuelle_Zaehlstelle_SVZ_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (manuelle_Zaehlstelle_SVZ_ID) REFERENCES Historisierung.historisches_Objekt,
   FOREIGN KEY (manuelle_Zaehlstelle_SVZ_ID) REFERENCES manuelle_Zaehlstelle_abstrakt,
   FOREIGN KEY (manuelle_Zaehlstelle_SVZ_ID) REFERENCES Verkehrsstaerke.Zaehlstelle,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Zaehlstellennummer
      VARCHAR(255) NOT NULL,
   hat_oertliche_Zuordnung
      INTEGER NOT NULL REFERENCES oertliche_Zuordnung_MZ,
   hat_verwaltungstechn_Zuordnung
      INTEGER NOT NULL REFERENCES verwaltungstechn_Zuordng_MZ,
   hat_raeuml_Gueltigkeitsbereich
      INTEGER NOT NULL REFERENCES raeuml_Gueltigkeitsbereich_MZ
)

CREATE TABLE man_Zaehlst_SVZ__h_autom_DZ (
   manuelle_Zaehlstelle_SVZ
      INTEGER NOT NULL REFERENCES manuelle_Zaehlstelle_SVZ,
   autom_Dauerzaehlst_abstrakt
      INTEGER NOT NULL REFERENCES automat_Dauerzaehlstelle.autom_Dauerzaehlst_abstrakt
)

CREATE TABLE manuelle_Zaehlstelle_abstrakt (
   manuelle_Zaehlstelle_abstr_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art_manuelle_Zaehlstelle_abstr
      INTEGER NOT NULL REFERENCES Art_manuelle_Zaehlstelle_abstr
)

CREATE TABLE Art_manuelle_Zaehlstelle_abstr (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(27) NOT NULL
)

INSERT INTO Art_manuelle_Zaehlstelle_abstr VALUES ( 17001, 'manuelle_Zaehlstelle_SVZ' )
INSERT INTO Art_manuelle_Zaehlstelle_abstr VALUES ( 17003, 'manuelle_Zaehlst_Symbol' )

CREATE TABLE manuelle_Zaehlst_Symbol (
   manuelle_Zaehlst_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (manuelle_Zaehlst_Symbol_ID) REFERENCES manuelle_Zaehlstelle_abstrakt,
   Kennung
      CHAR(8) NOT NULL
)

CREATE TABLE verwaltungstechn_Zuordng_MZ (
   verwaltungstechn_Zuordng_MZ_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (verwaltungstechn_Zuordng_MZ_ID) REFERENCES Administration.verwaltungstechn_Zuordnung
)

CREATE TABLE oertliche_Zuordnung_MZ (
   oertliche_Zuordnung_MZ_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (oertliche_Zuordnung_MZ_ID) REFERENCES Strassennetz.oertliche_Zuordnung,
   Richtung
      CHAR(1) REFERENCES Strassennetz.Bezugsrichtung
)

CREATE TABLE raeuml_Gueltigkeitsbereich_MZ (
   raeuml_Gueltigkeitsber_MZ_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (raeuml_Gueltigkeitsber_MZ_ID) REFERENCES Strassennetz.Streckenobjekt_hist,
   verbale_Beschreibung
      VARCHAR(255) NOT NULL,
   ueberwiegende_Anzahl_Fahrstr
      INTEGER NOT NULL REFERENCES Verkehr.Anzahl_Fahrstreifen
)

